netapp_ontap.models.cluster_nodes_ha_giveback_status_error API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_ha_giveback_status_error`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesHaGivebackStatusErrorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesHaGivebackStatusError object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: str GET`

    Message code.

    Example: 852126

  `message: str GET`

    Detailed message based on the state.

    Valid choices:

    - shutdown
    - not_homes_partner
    - not_sfo
    - failed_limbo
    - offline_failed
    - migrating
    - veto
    - communication_err
    - online_timeout
    - online_failed
    - hdd_to_aff_dest